# Configuration file for the Sphinx documentation builder.
#
# This file only contains a selection of the most common options. For a full
# list see the documentation:
# https://www.sphinx-doc.org/en/master/usage/configuration.html

# -- Path setup --------------------------------------------------------------

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))


# -- Project information -----------------------------------------------------

from datetime import date
try:
    from importlib.metadata import metadata
except ImportError:
    from importlib_metadata import metadata
import flask_uploader


meta_info = metadata(flask_uploader.__name__)

project = meta_info['Name']
copyright = '{}, {}'.format(date.today().year, meta_info['Author'])
author = meta_info['Author']

# The full version, including alpha/beta/rc tags
release = flask_uploader.__version__


# -- General configuration ---------------------------------------------------

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    'sphinx.ext.autodoc',
    'sphinx.ext.napoleon',
    # 'sphinx.ext.viewcode',
    'sphinx.ext.intersphinx',
    'sphinx.ext.autosectionlabel',
]
autosectionlabel_prefix_document = True

# Add any paths that contain templates here, relative to this directory.
templates_path = ['_templates']

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = 'ru'

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This pattern also affects html_static_path and html_extra_path.
exclude_patterns = []

# The name of the Pygments (syntax highlighting) style to use.
pygments_style = 'sphinx'

# -- Options for HTML output -------------------------------------------------

# The master toctree document.
master_doc = 'toc'

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = 'alabaster'
html_show_sourcelink = False

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ['_static']

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
html_theme_options = {
    'description': 'Загрузчик файлов для Flask с гибкой возможностью расширения',
    'show_related': True,
    'show_relbar_top': False,
    'show_relbar_bottom': True,
    'logo': 'logo.svg',
    'github_user': 'kyzima-spb',
    'github_repo': meta_info['Name'].lower(),
    'github_button': True,
    'github_type': 'star',
    'github_banner': True,
    'extra_nav_links': {
    },
}

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# The default sidebars (for documents that don't match any pattern) are
# defined by theme itself.  Builtin themes are using these templates by
# default: ``['localtoc.html', 'relations.html', 'sourcelink.html',
# 'searchbox.html']``.
#
# html_sidebars = {
#     '**': [
#         'about.html',
#         'navigation.html',
#         'relations.html',
#         'searchbox.html',
#         'donate.html',
#     ]
# }


# -- Options for intersphinx extension ---------------------------------------

intersphinx_mapping = {
    'python': ('https://docs.python.org/3', None),
    'flask': ('https://flask.palletsprojects.com/en/2.1.x/', None),
    'werkzeug': ('https://werkzeug.palletsprojects.com/en/2.1.x/', None),
    'flask_wtf': ('https://flask-wtf.readthedocs.io/en/1.0.x/', None),
    'flask_uploads': ('https://pythonhosted.org/Flask-Uploads/', None),
    'flask_pymongo': ('https://flask-pymongo.readthedocs.io/en/latest/', None),
    'gridfs': ('https://pymongo.readthedocs.io/en/stable/api/gridfs/', None),
    'boto3': ('https://boto3.amazonaws.com/v1/documentation/api/latest/index.html', None),
    'pymongo': ('https://pymongo.readthedocs.io/en/stable/', None),
}
